Imports Microsoft.VisualBasic
Imports System
Imports System.Data
Imports System.Configuration


'/ <summary>
'/ Represents a one piece of news 
'/ </summary>
Public Class NewsItem
    Private _id As String ' unique identifier
    Private _visible As Boolean ' whether to display
    Private _title As String ' brief descriptive name
    Private _date As DateTime ' date of the news
    Private _content As String ' main content of the news
    Private _imageUrl As String ' image associated with the news item
    Private _imageAltText As String ' in case the image can't be displayed

    ' <summary>
    ' Constructor
    ' </summary>
    Public Sub New(ByVal id As String, ByVal visible As Boolean, ByVal title As String)
        If [String].IsNullOrEmpty(id) Then
            Throw New ArgumentException(Messages.NewsItemIdUndefined)
        End If
        If [String].IsNullOrEmpty(title) Then
            Throw New ArgumentException(Messages.NewsItemTitleUndefined)
        End If
        _id = id
        _visible = visible
        _title = title
    End Sub 'New


    Public ReadOnly Property Id() As String
        Get
            Return _id
        End Get
    End Property


    Public Property Visible() As Boolean
        Get
            Return _visible
        End Get
        Set(ByVal value As Boolean)
            _visible = value
        End Set
    End Property


    Public Property Title() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_title)
        End Get
        Set(ByVal value As String)
            If [String].IsNullOrEmpty(value) Then
                Throw New InvalidOperationException(Messages.NewsItemTitleUndefined)
            End If
            _title = value
        End Set
    End Property



    Public Property [Date]() As DateTime
        Get
            Return _date
        End Get
        Set(ByVal value As DateTime)
            _date = value
        End Set
    End Property

    Public Property Content() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_content)
        End Get
        Set(ByVal value As String)
            _content = value
        End Set
    End Property

    Public Property ImageUrl() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_imageUrl)
        End Get
        Set(ByVal value As String)
            _imageUrl = value
        End Set
    End Property


    Public Property ImageAltText() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_imageAltText)
        End Get
        Set(ByVal value As String)
            _imageAltText = value
        End Set
    End Property
End Class 'NewsItem