Imports System
Imports System.Data
Imports System.Configuration
Imports System.Web
Imports System.Globalization

 _
'/ <summary>
'/ Represents a person
'/ </summary> 
Public Class Person
    Private _id As String
    Private _firstName As String
    Private _middleName As String
    Private _lastName As String

    Private _visible As Boolean
    Private _title As String
    Private _description As String

    ' contact info
    Private _email As String
    Private _phone As String
    Private _fax As String

    Private _streetAddress As String
    Private _city As String
    Private _state As String
    Private _country As String
    Private _postalCode As String

    Private _imageUrl As String
    Private _imageAltText As String


    Public Sub New(ByVal id As String, ByVal visible As Boolean, ByVal firstName As String, ByVal lastName As String)
        If [String].IsNullOrEmpty(id) Then
            Throw New ArgumentException(Messages.UndefinedId)
        End If
        If [String].IsNullOrEmpty(firstName) Then
            Throw New ArgumentException(Messages.UndefinedFirstName)
        End If
        If [String].IsNullOrEmpty(lastName) Then
            Throw New ArgumentException(Messages.UndefinedLastName)
        End If
        _id = id
        _firstName = firstName
        _lastName = lastName
        _visible = visible
    End Sub 'New



    Public ReadOnly Property Id() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_id)
        End Get
    End Property


    Public Property FirstName() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_firstName)
        End Get
        Set(ByVal value As String)
            If [String].IsNullOrEmpty(value) Then
                Throw New InvalidOperationException(Messages.UndefinedFirstName)
            End If
            _firstName = value
        End Set
    End Property



    Public Property MiddleName() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_middleName)
        End Get
        Set(ByVal value As String)
            _middleName = value
        End Set
    End Property

    Public Property LastName() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_lastName)
        End Get
        Set(ByVal value As String)
            If [String].IsNullOrEmpty(value) Then
                Throw New InvalidOperationException(Messages.UndefinedLastName)
            End If
            _lastName = value
        End Set
    End Property


    Public Property Visible() As Boolean
        Get
            Return _visible
        End Get
        Set(ByVal value As Boolean)
            _visible = value
        End Set
    End Property

    Public Property Title() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_title)
        End Get
        Set(ByVal value As String)
            _title = value
        End Set
    End Property

    Public Property Description() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_description)
        End Get
        Set(ByVal value As String)
            _description = value
        End Set
    End Property


    Public Property Email() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_email)
        End Get
        Set(ByVal value As String)
            _email = value
        End Set
    End Property


    Public Property Phone() As String
        Get
            If [String].IsNullOrEmpty(_phone) Then
                Return [String].Empty
            Else
                If CultureInfo.CurrentCulture.Name = "en-US" Then
                    Try
                        Dim usPhone As String = "(" + _phone.Substring(0, 3) + ") " + _phone.Substring(3, 3) + "-" + _phone.Substring(6)
                        Return usPhone
                    Catch
                        Return _phone
                    End Try
                Else
                    Return _phone
                End If
            End If
        End Get
        Set(ByVal value As String)
            _phone = value
        End Set
    End Property

    Public Property Fax() As String
        Get
            If [String].IsNullOrEmpty(_fax) Then
                Return [String].Empty
            Else
                If CultureInfo.CurrentCulture.Name = "en-US" Then
                    Try
                        Dim usFax As String = "(" + _fax.Substring(0, 3) + ") " + _fax.Substring(3, 3) + "-" + _fax.Substring(6)
                        Return usFax
                    Catch e As ArgumentOutOfRangeException
                        Return _fax
                    End Try

                Else
                    Return _fax
                End If
            End If
        End Get
        Set(ByVal value As String)
            _fax = value
        End Set
    End Property

    Public Property StreetAddress() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_streetAddress)
        End Get
        Set(ByVal value As String)
            _streetAddress = value
        End Set
    End Property


    Public Property City() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_city)
        End Get
        Set(ByVal value As String)
            _city = value
        End Set
    End Property


    Public Property PostalCode() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_postalCode)
        End Get
        Set(ByVal value As String)
            _postalCode = value
        End Set
    End Property


    Public Property State() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_state)
        End Get
        Set(ByVal value As String)
            _state = value
        End Set
    End Property

    Public Property Country() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_country)
        End Get
        Set(ByVal value As String)
            _country = value
        End Set
    End Property


    Public Property ImageUrl() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_imageUrl)
        End Get
        Set(ByVal value As String)
            _imageUrl = value
        End Set
    End Property

    Public Property ImageAltText() As String
        Get
            Return Util.ReturnEmptyStringIfNull(_imageAltText)
        End Get
        Set(ByVal value As String)
            _imageAltText = value
        End Set
    End Property
End Class 'Person 
