Imports Microsoft.VisualBasic
Imports System
Imports System.Collections.Generic
Imports System.Configuration
Imports System.Web.Configuration

'/<summary>
'/ class Catalog
'/ Provides static functions to access items & categories 
'/ and serves as abastraction layer between the web Page and
'/ actual data providers
'/</summary>
Public Class Catalog
    Private Shared _isInitialized As Boolean = False
    Private Shared _provider As CatalogProvider
    Private Shared _providersSection As SmallBusinessDataProvidersSection

    '/<summary>
    '/ returns the current items data provider
    '/</summary>    
    Public Shared ReadOnly Property Provider() As CatalogProvider
        Get
            Initialize()
            Return _provider
        End Get
    End Property


    '<summary>
    ' Returns item belonging to the category having id: 'parentCategoryId' 
    '</summary>
    Public Shared Function GetChildItems(ByVal categoryId As String) As List(Of Item)

        Return Provider.GetChildItems(categoryId)
    End Function


    '<summary>
    ' Returns subcategories under the category having id: 'parentCategoryId'
    '</summary>
    Public Shared Function GetChildCategories(ByVal parentCategoryId As String) As List(Of Category)

        Return Provider.GetChildCategories(parentCategoryId)
    End Function


    '<summary>
    ' Returns an item matching the id
    '</summary>
    Public Shared Function GetItem(ByVal itemId As String) As Item
        Return Provider.GetItem(itemId)
    End Function



    '<summary>
    'Initilizes a concrete data provider based on setting in web.config
    'InvalidOperationException may be thrown if an actual provider cannot be instantiated
    '</summary>
    Private Shared Sub Initialize()
        If Not _isInitialized Then
            _providersSection = ConfigurationManager.GetSection("SmallBusinessDataProviders") '

            If _providersSection Is Nothing Then
                Throw New InvalidOperationException(Messages.ItemConfigNotFound)
            End If
            _provider = ProvidersHelper.InstantiateProvider(_providersSection.CatalogProviders(_providersSection.CatalogProviderName), GetType(CatalogProvider))

            If _provider Is Nothing Then
                Throw New InvalidOperationException(Messages.ItemProviderInstantiationError)
            End If
            _isInitialized = True
        End If
    End Sub 'Initialize
End Class 'Catalog


