Imports System
Imports System.Configuration
Imports System.Web.Configuration
Imports System.Data
Imports System.Data.SqlClient
Imports System.Collections.Generic


'/ <summary>
'/Provides access to SqlServer data source 
'/ </summary>
Public Class SqlCatalogProvider
    Inherits CatalogProvider


    Private Function connectionString() As String
        Dim sec As SmallBusinessDataProvidersSection = ConfigurationManager.GetSection("SmallBusinessDataProviders") '
        Dim connectionStringName As String = sec.CatalogProviders(sec.CatalogProviderName).Parameters("connectionStringName")
        Return WebConfigurationManager.ConnectionStrings(connectionStringName).ConnectionString
    End Function 'connectionString

    '<summary>
    '  Returns item belonging to the category having id: 'parentCategoryId'
    '  if price is not specified Double.MinValue is returned
    '</summary>
    Public Overrides Function GetChildItems(ByVal parentCategoryId As String) As List(Of Item)

        Dim list As New List(Of Item)

        If [String].IsNullOrEmpty(parentCategoryId) Then
            Return list
        End If

        ' connect to the database
        Dim con As New SqlConnection(connectionString())
        Try
            con.Open()
            Dim cmd As New SqlCommand("GetChildItems", con)
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Parameters.Add("@categoryId", SqlDbType.NVarChar)
            cmd.Parameters("@categoryId").Value = parentCategoryId

            Dim r As SqlDataReader = cmd.ExecuteReader()
            Dim curr As Item

            While r.Read()
                If TypeOf r("id") Is DBNull Or TypeOf r("visible") Is DBNull Or TypeOf r("title") Is DBNull Then
                    Throw New InvalidOperationException(Messages.ItemRequiredAttributesMissing)
                End If
                curr = New Item(CStr(r("id")), CType(r("visible"), [Boolean]), CStr(r("title")))
                curr.Description = Util.ReturnEmptyStringIfDbNull(r("description"))
                curr.Price = Util.ReturnEmptyStringIfDbNull(r("price"))
                If (TypeOf r("inStock") Is DBNull) Then
                    curr.InStock = True
                Else
                    curr.InStock = r("inStock")
                End If
                curr.ImageUrl = Util.ReturnEmptyStringIfDbNull(r("imageUrl"))
                curr.ImageAltText = Util.ReturnEmptyStringIfDbNull(r("imageAltText"))
                list.Add(curr)
            End While
            con.Close()
        Finally
            con.Dispose()
        End Try
        Return list
    End Function 'New

    '/<summary>
    '/ Returns subcategories under the category having id: 'parentCategoryId'    
    '/</summary>
    Public Overrides Function GetChildCategories(ByVal parentCategoryId As String) As List(Of Category)
        Dim list As New List(Of Category)
        Dim con As New SqlConnection(connectionString())
        Try
            con.Open()
            Dim cmd As SqlCommand
            If [String].IsNullOrEmpty(parentCategoryId) Then
                cmd = New SqlCommand("GetRootCategories", con)
            Else
                cmd = New SqlCommand("GetNonRootCategories ", con)
                cmd.CommandType = CommandType.StoredProcedure
                cmd.Parameters.Add("@categoryId", SqlDbType.NVarChar)
                cmd.Parameters("@categoryId").Value = parentCategoryId
            End If

            Dim r As SqlDataReader = cmd.ExecuteReader()
            Dim curr As Category
            While r.Read()
                If TypeOf r("id") Is DBNull Or TypeOf r("visible") Is DBNull Or TypeOf r("title") Is DBNull Then
                    Throw New InvalidOperationException(Messages.CategoryRequiredAttributesMissing)
                End If
                curr = New Category(CStr(r("id")), CType(r("visible"), [Boolean]), CStr(r("title")))
                curr.Description = Util.ReturnEmptyStringIfDbNull(r("description"))
                curr.ImageUrl = Util.ReturnEmptyStringIfDbNull(r("imageUrl"))
                curr.ImageAltText = Util.ReturnEmptyStringIfDbNull(r("imageAltText"))
                list.Add(curr)
            End While
            con.Close()
        Finally
            con.Dispose()
        End Try
        Return List
    End Function 'New


    '/<summary>
    '/ Returns item having the id 'itemId'
    '/</summary>
    Public Overrides Function GetItem(ByVal itemId As String) As Item
        If [String].IsNullOrEmpty(itemId) Then
            Return Nothing
        End If ' connect to the database
        Dim curr As Item
        Dim con As New SqlConnection(connectionString())
        Try
            con.Open()
            Dim cmd As New SqlCommand("GetItem", con)
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Parameters.Add("@itemId", SqlDbType.NVarChar)
            cmd.Parameters("@itemId").Value = itemId

            Dim r As SqlDataReader = cmd.ExecuteReader()
            r.Read()

            If TypeOf r("id") Is DBNull Or TypeOf r("visible") Is DBNull Or TypeOf r("title") Is DBNull Then
                Throw New InvalidOperationException(Messages.ItemRequiredAttributesMissing)
            End If
            curr = New Item(CStr(r("id")), CType(r("visible"), [Boolean]), CStr(r("title")))
            curr.Description = Util.ReturnEmptyStringIfDbNull(r("description"))
            curr.Price = Util.ReturnEmptyStringIfDbNull(r("price"))
            If (TypeOf r("inStock") Is DBNull) Then
                curr.InStock = True
            Else
                curr.InStock = r("inStock")
            End If
            curr.ImageUrl = Util.ReturnEmptyStringIfDbNull(r("imageUrl"))
            curr.ImageAltText = Util.ReturnEmptyStringIfDbNull(r("imageAltText"))
        Finally
            con.Dispose()
        End Try
        Return curr
    End Function 'GetItem 


End Class 'SqlCatalogProvider 