Imports System
Imports System.Data
Imports System.Configuration
Imports System.Web
Imports System.Xml
Imports System.Xml.Schema
Imports System.IO
Imports System.Collections.Generic


' <summary>
' XML Data Layer for Items and Cateogories
' </summary>
Public Class XmlCatalogProvider
    Inherits CatalogProvider

    Private _xmlFile As String
    Private _xsdFile As String



    Public Sub New()
        Dim sec As SmallBusinessDataProvidersSection = ConfigurationManager.GetSection("SmallBusinessDataProviders")
        Dim xmlFile As String = sec.CatalogProviders(sec.CatalogProviderName).Parameters("dataFile")
        Dim xsdFile As String = sec.CatalogProviders(sec.CatalogProviderName).Parameters("schemaFile")

        _xmlFile = HttpContext.Current.Request.MapPath(("~/App_Data/" + xmlFile))
        _xsdFile = HttpContext.Current.Request.MapPath(("~/App_Data/schemas/" + xsdFile))
    End Sub 'New 



    ' <summary>
    ' Returns child categories of a given cateogory
    ' If 'parentCategoryId' = null , top level categories are returned
    ' </summary>
    Public Overrides Function GetChildCategories(ByVal parentCategoryId As String) As List(Of Category)

        If [String].IsNullOrEmpty(parentCategoryId) Then
            parentCategoryId = "NULL"
        End If
        Dim dataSet As DataSet = Util.ReadAndValidateXml(_xmlFile, _xsdFile)

        ' tables, in order in the dataset: category | childItemId| item
        Dim categoryTbl As DataTable = dataSet.Tables(0)
        Dim list As New List(Of Category)
        Dim r As DataRow
        For Each r In categoryTbl.Rows
            If CStr(r("parentCategoryId")) = parentCategoryId Then ' match found
                If TypeOf r("id") Is DBNull Or TypeOf r("visible") Is DBNull Or TypeOf r("title") Is DBNull Then
                    Throw New InvalidOperationException(Messages.CategoryRequiredAttributesMissing)
                End If
                Dim curr As New Category(CStr(r("id")), [Boolean].Parse(CStr(r("visible"))), CStr(r("title")))
                curr.Description = Util.ReturnEmptyStringIfDbNull(r("description"))
                curr.ImageUrl = Util.ReturnEmptyStringIfDbNull(r("imageUrl"))
                curr.ImageAltText = Util.ReturnEmptyStringIfDbNull(r("imageAltText"))
                list.Add(curr)
            End If
        Next r
        Return list
    End Function 'New



    ' <summary>
    ' Returns child items of a given cateogory
    ' Returns empty list if 'parentCategoryId' = null ,
    ' </summary>
    Public Overrides Function GetChildItems(ByVal parentCategoryId As String) As List(Of Item)

        Dim itemList As New List(Of Item)

        If [String].IsNullOrEmpty(parentCategoryId) Then
            Return itemList
        End If
        Dim dataSet As DataSet = Util.ReadAndValidateXml(_xmlFile, _xsdFile)

        ' find index correspondig to parentCategorId
        Dim categoryTbl As DataTable = dataSet.Tables(0)
        Dim index As Integer = -1
        Dim counter As Integer = 0
        Dim r As DataRow
        For Each r In categoryTbl.Rows
            If CStr(r("id")) = parentCategoryId Then
                index = counter
                Exit For
            End If
            counter += 1
        Next r

        ' populate the list of child items ids and then construct Item objects
        Dim categorizationTbl As DataTable = dataSet.Tables(1)
        Dim childItemIds As New List(Of String)


        For Each r In categorizationTbl.Rows
            If CInt(r("category_Id")) = index Then
                childItemIds.Add(CStr(r("childItemId_Text")))
            End If
        Next r

        Dim itemsTbl As DataTable = dataSet.Tables(2)
        Dim curr As Item

        For Each r In itemsTbl.Rows
            If childItemIds.Contains(CStr(r("id"))) Then
                If TypeOf r("id") Is DBNull Or TypeOf r("visible") Is DBNull Or TypeOf r("title") Is DBNull Then
                    Throw New InvalidOperationException(Messages.ItemRequiredAttributesMissing)
                End If
                curr = New Item(CStr(r("id")), [Boolean].Parse(CStr(r("visible"))), CStr(r("title")))
                curr.Description = Util.ReturnEmptyStringIfDbNull(r("description"))
                curr.Price = Util.ReturnEmptyStringIfDbNull(r("price"))
                If (TypeOf r("inStock") Is DBNull) Then
                    curr.InStock = True
                Else
                    curr.InStock = r("inStock")
                End If
                curr.ImageUrl = Util.ReturnEmptyStringIfDbNull(r("imageUrl"))
                curr.ImageAltText = Util.ReturnEmptyStringIfDbNull(r("imageAltText"))
                itemList.Add(curr)
            End If
        Next r
        Return itemList
    End Function 'New

    '/<summary>
    '/ Returns item having the id 'itemId'
    '/</summary>
    Public Overrides Function GetItem(ByVal itemId As String) As Item
        If [String].IsNullOrEmpty(itemId) Then
            Return Nothing
        End If
        Dim dataSet As DataSet = Util.ReadAndValidateXml(_xmlFile, _xsdFile)

        Dim itemsTbl As DataTable = dataSet.Tables(2)
        Dim curr As Item = Nothing
        Dim r As DataRow
        For Each r In itemsTbl.Rows
            If TypeOf r("id") Is DBNull Then
                Throw New InvalidOperationException(Messages.ItemRequiredAttributesMissing)
            End If
            If itemId = CStr(r("id")) Then
                ' assert: r[id] is not DBNull
                If TypeOf r("visible") Is DBNull Or TypeOf r("title") Is DBNull Then
                    Throw New InvalidOperationException(Messages.ItemRequiredAttributesMissing)
                End If
                curr = New Item(CStr(r("id")), [Boolean].Parse(CStr(r("visible"))), CStr(r("title")))
                curr.Description = Util.ReturnEmptyStringIfDbNull(r("description"))
                curr.Price = Util.ReturnEmptyStringIfDbNull(r("price"))
                If (TypeOf r("inStock") Is DBNull) Then
                    curr.InStock = True
                Else
                    curr.InStock = r("inStock")
                End If
                curr.ImageUrl = Util.ReturnEmptyStringIfDbNull(r("imageUrl"))
                curr.ImageAltText = Util.ReturnEmptyStringIfDbNull(r("imageAltText"))
            End If
        Next r
        Return curr
    End Function 'GetItem




End Class 'XmlCatalogProvider