Imports System
Imports System.Configuration
Imports System.Web.Configuration
Imports System.Data.SqlClient
Imports System.Collections.Generic
Imports System.Data


'/ <summary>
'/ class  SqlNewsProvider 
'/ Provides access to SqlServer data source
'/ </summary>
Public Class SqlNewsProvider
    Inherits NewsProvider

    '/ <summary>
    '/ Reads xml and xsd file names from the web.config file
    '/ </summary>
    Private Function connectionString() As String
        Dim sec As SmallBusinessDataProvidersSection = ConfigurationManager.GetSection("SmallBusinessDataProviders") '       
        Dim connectionStringName As String = sec.NewsProviders(sec.NewsProviderName).Parameters("connectionStringName")
        Return WebConfigurationManager.ConnectionStrings(connectionStringName).ConnectionString
    End Function 'connectionString


    ' <summary>
    ' DateTime.MinValue returned if no date is specified
    ' </summary>
    Public Overrides Function GetAllNews() As List(Of NewsItem)

        Dim list As List(Of NewsItem) = New List(Of NewsItem)

        ' create a connection, invoke a stored procedure and add results to a list
        Dim con As New SqlConnection(connectionString())
        Try
            con.Open()
            Dim cmd As New SqlCommand("GetNews", con)
            Dim r As SqlDataReader = cmd.ExecuteReader()
            Dim curr As NewsItem
            While r.Read()
                If TypeOf r("id") Is DBNull Or TypeOf r("visible") Is DBNull Or TypeOf r("title") Is DBNull Then
                    Throw New InvalidOperationException(Messages.NewsItemRequiredAttributesMissing)
                End If
                curr = New NewsItem(CStr(r("id")), CType(r("visible"), [Boolean]), CStr(r("title")))
                curr.Date = Util.ReturnEmptyStringIfDbNull(r("date"))
                curr.Content = Util.ReturnEmptyStringIfDbNull(r("content"))
                curr.ImageUrl = Util.ReturnEmptyStringIfDbNull(r("imageUrl"))
                curr.ImageAltText = Util.ReturnEmptyStringIfDbNull(r("imageAltText"))
                list.Add(curr)
            End While
            con.Close()
        Finally
            con.Dispose()
        End Try

        Return List
    End Function 'New

    ' <summary>
    ' Returns a particular news item
    ' </summary>
    Public Overrides Function GetNewsItem(ByVal newsItemId As String) As NewsItem

        If [String].IsNullOrEmpty(newsItemId) Then
            Return Nothing
        End If
        ' connect to the database
        Dim curr As NewsItem
        Dim con As New SqlConnection(connectionString())
        Try
            con.Open()
            Dim cmd As New SqlCommand("GetNewsItem", con)
            cmd.CommandType = CommandType.StoredProcedure
            cmd.Parameters.Add("@id", SqlDbType.NVarChar)
            cmd.Parameters("@id").Value = newsItemId

            Dim r As SqlDataReader = cmd.ExecuteReader()

            r.Read()

            If TypeOf r("id") Is DBNull Or TypeOf r("visible") Is DBNull Or TypeOf r("title") Is DBNull Then
                Throw New InvalidOperationException(Messages.NewsItemRequiredAttributesMissing)
            End If
            curr = New NewsItem(CStr(r("id")), CType(r("visible"), [Boolean]), CStr(r("title")))
            curr.Date = Util.ReturnEmptyStringIfDbNull(r("date"))
            curr.Content = Util.ReturnEmptyStringIfDbNull(r("content"))
            curr.ImageUrl = Util.ReturnEmptyStringIfDbNull(r("imageUrl"))
            curr.ImageAltText = Util.ReturnEmptyStringIfDbNull(r("imageAltText"))
        Finally
            con.Dispose()
        End Try

        Return curr

    End Function 'GetNewsItem

End Class 'SqlNewsProvider 
