Imports System
Imports System.Web
Imports System.Web.UI.WebControls
Imports System.Xml
Imports System.Xml.Schema
Imports System.Data
Imports System.IO

' <summary>
' Provides util functions
' </summary>
Public Class Util
    Private Shared lockObj As New [Object]()


    ' <summary>
    ' Callback function invoked on xml validation errors
    ' </summary>
    Private Shared Sub ValidationEventHandler(ByVal sender As Object, ByVal e As ValidationEventArgs)
        SyncLock lockObj
            Select Case e.Severity
                Case XmlSeverityType.Error

                Case XmlSeverityType.Warning
            End Select
        End SyncLock
    End Sub 'ValidationEventHandler



    ' <summary>
    ' Validates the xml file well formed and confirms to the schema 
    ' function is static as used by other classes as well
    ' </summary>
    Private Shared Sub ValidateXml(ByVal xmlFilePath As String, ByVal schemaFilePath As String)
        ' create a schema set and copy it to settings.Schemas
        Dim schema As New XmlSchemaSet()
        schema.Add(Nothing, schemaFilePath)

        Dim settings As New XmlReaderSettings()
        settings.ValidationType = ValidationType.Schema
        settings.Schemas.Add(schema)

        ' Parse the xml data file. 
        Dim reader As XmlReader = XmlReader.Create(xmlFilePath, settings)
        Try
            Dim xmlDoc As New XmlDocument()
            xmlDoc.Load(reader)
            Dim eventHandler As New ValidationEventHandler(AddressOf ValidationEventHandler)
            xmlDoc.Validate(eventHandler)
        Finally
            reader.Close()
        End Try
    End Sub 'ValidateXml



    ' <summary>
    ' Reads the 'xmlFile' and validates it against the scehma in 'xsdFile'. Returns dataset containing xml file data
    ' </summary>
    Public Shared Function ReadAndValidateXml(ByVal xmlFilePath As String, ByVal schemaFilePath As String) As DataSet
        Dim dataSet As DataSet = Nothing
        Util.ValidateXml(xmlFilePath, schemaFilePath)
        Dim fs_xml As New FileStream(xmlFilePath, FileMode.Open, FileAccess.Read)
        Try
            Dim fs_xsd As New FileStream(schemaFilePath, FileMode.Open, FileAccess.Read)
            Try
                dataSet = New DataSet()
                dataSet.ReadXmlSchema(fs_xsd)
                dataSet.ReadXml(fs_xml, XmlReadMode.IgnoreSchema)
            Finally
                fs_xsd.Dispose()
            End Try
        Finally
            fs_xml.Dispose()
        End Try

        Return dataSet
    End Function 'ReadAndValidateXml


    Public Shared Function ReturnEmptyStringIfDbNull(ByRef sqlVar As Object)
        Dim ret As String
        If TypeOf sqlVar Is DBNull Then
            ret = String.Empty
        Else
            ret = CStr(sqlVar)
        End If
        Return ret
    End Function

    Public Shared Function ReturnEmptyStringIfNull(ByRef var As String)
        Dim ret As String
        If var Is Nothing Then
            ret = String.Empty
        Else
            ret = var
        End If
        Return ret
    End Function


End Class 'Util